@@ -37,4 +37,4 @@ def send_most_money():
     s.maximize(money)
     s.branch(letters,INT_VAR_SIZE_MIN,INT_VAL_MIN)
     for s2 in s.search():
-        print s2.val(money), s2.val(letters)
+        print(s2.val(money), s2.val(letters))
